@@ -13,8 +13,8 @@ gmt makecpt -Ccategorical > categories.cpt
 
 gmt gmt2kml "${src:-.}"/pointsets.txt -Ccategories.cpt | \
 	sed -e 's/st-.*-/st-x-/' > pointsets.kml
-diff --strip-trailing-cr pointsets.kml "${src:-.}"/pointsets.kml > fail
+diff --strip-trailing-cr pointsets.kml "${src:-.}"/pointsets.kml >> fail
 
 gmt gmt2kml "${src:-.}"/lines.txt -Fl -Ccategories.cpt | \
 	sed -e 's/st-.*-/st-x-/' > lines.kml
-diff --strip-trailing-cr lines.kml "${src:-.}"/lines.kml > fail
+diff --strip-trailing-cr lines.kml "${src:-.}"/lines.kml >> fail
